==> bucket_adapter-0.1.3.tar.gz: bucket_adapter-0.1.3/bucket_adapter/gcp/adapter.py <==
"""GCP class file"""

import os
from google.cloud import storage
from google.oauth2 import service_account
from google.oauth2.service_account import Credentials

class GCP(object):
    """GCP.

    Args:
        object ([type]): [description]

    Returns:
        [type]: [description]
    """

    REQUIRED_FIELDS = [
        'CREDENTIAL_FILE','PROJECT_NAME','BUCKET_NAME'
    ]

    def upload(self,filename, options):
        """upload function to uplaod the file to gcp bucket.

        Args:
            filename ([type]): [description]
            options ([type]): [description]

        Returns:
            [type]: [description]
        """
        try:
            credentials = service_account.Credentials.from_service_account_file(
                options['CREDENTIAL_FILE'])
            client = storage.Client(
                credentials=credentials, project=options['PROJECT_NAME'])
            bucket = client.get_bucket(options['BUCKET_NAME'])
            blob = bucket.blob(filename)
            blob.upload_from_filename(filename)
            return blob.public_url
        except Exception as E:
            print("Exception", E)

    def download(self, file_name, options):
        """download function to download the file from gcp bucket.

        Args:
            file_name ([type]): [description]
            options ([type]): [description]

        Returns:
            [type]: [description]
        """
        print("download_file")
        credentials = service_account.Credentials.from_service_account_file(options['CREDENTIAL_FILE'])
        client = storage.Client(credentials=credentials, project=options['PROJECT_NAME'])
        # storage_client = storage.Client.from_service_account_json(
        #     credentials_file)
        bucket = client.get_bucket(options['BUCKET_NAME'])
        blob = bucket.get_blob(file_name)
        blob.download_to_filename('home/Downloads')
        print("name ",blob.name)
        return storage_name

==> bucket_adapter-0.2.1a0.tar.gz: bucket_adapter-0.2.1a0/bucket_adapter/gcp/adapter.py <==
"""GCP class file"""

import os
from google.cloud import storage
from google.oauth2 import service_account
from google.oauth2.service_account import Credentials

class GCP(object):
    """GCP.

    Args:
        object ([type]): [description]

    Returns:
        [type]: [description]
    """

    REQUIRED_FIELDS = [
        'CREDENTIAL_FILE','PROJECT_NAME','BUCKET_NAME'
    ]

    def upload(self,filename, options):
        """upload function to uplaod the file to gcp bucket.

        Args:
            filename ([type]): [description]
            options ([type]): [description]

        Returns:
            [type]: [description]
        """
        try:
            credentials = service_account.Credentials.from_service_account_file(
                options['CREDENTIAL_FILE'])
            client = storage.Client(
                credentials=credentials, project=options['PROJECT_NAME'])
            bucket = client.get_bucket(options['BUCKET_NAME'])
            blob = bucket.blob(filename)
            blob.upload_from_filename(filename)
            return blob.public_url
        except Exception as E:
            print("Exception", E)

    def download(self, file_name, options):
        """Generates a v2 signed URL for downloading a blob.
        Note that this method requires a service account key file. You can not use
        this if you are using Application Default Credentials from Google Compute
        Engine or from the Google Cloud SDK.


        Args:
            file_name ([type]): [description]
            options ([type]): [description]

        Returns:
            [type]: [description]
        """
        credentials = service_account.Credentials.from_service_account_file(options['CREDENTIAL_FILE'])
        storage_client = storage.Client(credentials=credentials,project=options['PROJECT_NAME'])
        bucket = storage_client.bucket(options['BUCKET_NAME'])
        blob = bucket.blob(blob_name=filename)

        url = blob.generate_signed_url(
            expiration=datetime.timedelta(hours=1),
            method="GET",
        )
        print("The signed url for {} is {}".format(blob.name, url))
        return url
